@@ -4,7 +4,7 @@ use warnings;
 use parent 'App::bif::Context';
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.0_27';
+our $VERSION = '0.1.0_28';
 
 sub run {
     my $self = __PACKAGE__->new(shift);
@@ -61,12 +61,12 @@ sub run {
             my $id       = $db->nextval('topics');
             my $topic_id = $db->nextval('topics');
 
-            my $uid = $self->new_update( message => $self->{message}, );
+            my $uid = $self->new_change( message => $self->{message}, );
 
             $db->xdo(
                 insert_into => 'func_new_topic',
                 values      => {
-                    update_id => $uid,
+                    change_id => $uid,
                     id        => $topic_id,
                     kind      => 'issue',
                 },
@@ -77,24 +77,24 @@ sub run {
                 values      => {
                     id        => $id,
                     topic_id  => $topic_id,
-                    update_id => $uid,
+                    change_id => $uid,
                     status_id => $self->{status_id},
                     title     => $self->{title},
                 },
             );
 
             $db->xdo(
-                insert_into => 'update_deltas',
+                insert_into => 'change_deltas',
                 values      => {
-                    update_id         => $uid,
+                    change_id         => $uid,
                     new               => 1,
-                    action_format     => "new issue %s",
+                    action_format     => "new issue (%s)",
                     action_topic_id_1 => $topic_id,
                 },
             );
 
             $db->xdo(
-                insert_into => 'func_merge_updates',
+                insert_into => 'func_merge_changes',
                 values      => { merge => 1 },
             );
 
@@ -103,7 +103,7 @@ sub run {
             # For test scripts
             $self->{id}        = $id;
             $self->{topic_id}  = $topic_id;
-            $self->{update_id} = $uid;
+            $self->{change_id} = $uid;
         }
     );
 
@@ -119,7 +119,7 @@ bif-new-issue - add a new issue to a project
 
 =head1 VERSION
 
-0.1.0_27 (2014-09-10)
+0.1.0_28 (2014-09-23)
 
 =head1 SYNOPSIS
 
