@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use parent 'App::bif::Context';
 
-our $VERSION = '0.1.0_27';
+our $VERSION = '0.1.0_28';
 
 sub run {
     my $self = __PACKAGE__->new(shift);
@@ -23,11 +23,11 @@ sub run {
 
     if ( $self->{reply} ) {
         my $uinfo =
-          $self->get_update( $self->{reply}, $info->{first_update_id} );
+          $self->get_change( $self->{reply}, $info->{first_change_id} );
         $self->{parent_uid} = $uinfo->{id};
     }
     else {
-        $self->{parent_uid} = $info->{first_update_id};
+        $self->{parent_uid} = $info->{first_change_id};
     }
 
     $self->{message} ||= $self->prompt_edit( opts => $self );
@@ -40,25 +40,25 @@ sub run {
 
     $db->txn(
         sub {
-            my $uid = $self->new_update(
+            my $uid = $self->new_change(
                 message   => $self->{message},
                 parent_id => $self->{parent_uid},
             );
 
             $db->xdo(
-                insert_into => 'func_update_project',
+                insert_into => 'func_change_project',
                 values      => {
                     id        => $info->{id},
-                    update_id => $uid,
+                    change_id => $uid,
                     $self->{title} ? ( title     => $self->{title} )   : (),
                     $status_ids    ? ( status_id => $status_ids->[0] ) : (),
                 },
             );
 
             $db->xdo(
-                insert_into => 'update_deltas',
+                insert_into => 'change_deltas',
                 values      => {
-                    update_id         => $uid,
+                    change_id         => $uid,
                     new               => 1,
                     action_format     => "update project $path (%s)",
                     action_topic_id_1 => $info->{id},
@@ -66,20 +66,20 @@ sub run {
             );
 
             $db->xdo(
-                insert_into => 'func_merge_updates',
+                insert_into => 'func_merge_changes',
                 values      => { merge => 1 },
             );
 
-            $self->{update_id} = $uid;
+            $self->{change_id} = $uid;
         }
     );
 
-    print "Project updated: $path.$self->{update_id}\n";
+    print "Project changed: $path.$self->{change_id}\n";
 
     # For testing
     $self->{id}     = $info->{id};
     $self->{status} = $status_ids;
-    return $self->ok('UpdateProject');
+    return $self->ok('ChangeProject');
 }
 
 1;
@@ -91,7 +91,7 @@ bif-update-project - update a project
 
 =head1 VERSION
 
-0.1.0_27 (2014-09-10)
+0.1.0_28 (2014-09-23)
 
 =head1 SYNOPSIS
 
