@@ -1,5 +1,5 @@
 CREATE TABLE func_import_hub(
-    update_uuid VARCHAR(40) NOT NULL,
+    change_uuid VARCHAR(40) NOT NULL,
     topic_uuid VARCHAR(40) NOT NULL,
     name VARCHAR(128) NOT NULL
 );
@@ -12,29 +12,29 @@ FOR EACH ROW
 BEGIN
 
     SELECT debug(
-        NEW.update_uuid,
+        NEW.change_uuid,
         NEW.topic_uuid,
         NEW.name
     );
 
     INSERT INTO
         func_new_hub(
-            update_id,
+            change_id,
             id,
             name
         )
     SELECT
-        u.id,
+        c.id,
         t.id,
         NEW.name
     FROM
-        updates u
+        changes c
     INNER JOIN
         topics t
     ON
         t.uuid = NEW.topic_uuid
     WHERE
-        u.uuid = NEW.update_uuid
+        c.uuid = NEW.change_uuid
     ;
 
     SELECT RAISE(IGNORE);
