@@ -1,5 +1,5 @@
 CREATE TABLE func_import_task(
-    update_uuid VARCHAR(40) NOT NULL,
+    change_uuid VARCHAR(40) NOT NULL,
     topic_uuid VARCHAR(40) NOT NULL,
     task_status_uuid VARCHAR(40),
     title VARCHAR(1024)
@@ -14,7 +14,7 @@ FOR EACH ROW
 BEGIN
 
     SELECT debug(
-        NEW.update_uuid,
+        NEW.change_uuid,
         NEW.topic_uuid,
         NEW.task_status_uuid,
         NEW.title
@@ -22,18 +22,18 @@ BEGIN
 
     INSERT INTO
         func_new_task(
-            update_id,
+            change_id,
             id,
             status_id,
             title
         )
     SELECT
-        u.id,
+        c.id,
         t.id,
         ts.id,
         NEW.title
     FROM
-        updates u
+        changes c
     INNER JOIN
         topics t
     ON
@@ -43,7 +43,7 @@ BEGIN
     ON
         ts.uuid = NEW.task_status_uuid
     WHERE
-        u.uuid = NEW.update_uuid
+        c.uuid = NEW.change_uuid
     ;
 
     SELECT RAISE(IGNORE);
