@@ -1,5 +1,5 @@
-CREATE TABLE func_update_entity(
-    update_id INTEGER NOT NULL,
+CREATE TABLE func_change_entity(
+    change_id INTEGER NOT NULL,
     id INTEGER NOT NULL,
     name VARCHAR,
     contact_id INTEGER,
@@ -7,14 +7,14 @@ CREATE TABLE func_update_entity(
 );
 
 CREATE TRIGGER
-    func_update_entity_bi_1
+    func_change_entity_bi_1
 BEFORE INSERT ON
-    func_update_entity
+    func_change_entity
 FOR EACH ROW BEGIN
 
     SELECT debug(
         NEW.id,
-        NEW.update_id,
+        NEW.change_id,
         NEW.name,
         NEW.contact_id,
         NEW.default_contact_method_id
@@ -22,14 +22,14 @@ FOR EACH ROW BEGIN
 
     INSERT INTO
         entity_deltas(
-            update_id,
+            change_id,
             entity_id,
             name,
             contact_id,
             default_contact_method_id
         )
     VALUES(
-        NEW.update_id,
+        NEW.change_id,
         NEW.id,
         NEW.name,
         NEW.contact_id,
